Enum ContainerNode

pub enum ContainerNode {}
Tag to be used in SGNode. SGNode is a node that simply contains other node. Either all the node have the same type, but the number of nodes is not known at compile time, or the child node can have different type, but the amount of nodes is known at compile time